=================
Bottle Utils Meta
=================

Bottle Utils is a collection of loosely related packages for developing web
applications using Bottle_ web framework. This package contains the page/social
metadata helpers.

.. _Bottle: http://bottlepy.org/

